ghtml/codegen

Gleam code generator from parsed templates.

Transforms the parsed AST into valid Gleam source code that uses the Lustre library to render HTML elements. Generated code is formatted to be compliant with gleam format.

Values

pub fn generate(
  template: types.Template,
  source_path: String,
  hash: String,
) -> String

Generate Gleam code from a parsed template

Search Document